clear

coefs=importdata('cellcoefs.csv');
coefs=coefs.data;

pi=coefs(:,1);
b1=coefs(:,2);
b2=coefs(:,3);
a=coefs(:,4);

J=length(a);
F=@(x)exp(b1.*repmat(x,J,1) + b2.*repmat(x,J,1).^2 + a)./(1+exp(b1.*repmat(x,J,1) + b2.*repmat(x,J,1).^2 + a));

k=99;
step=1/(1+k);

tol=1e-10;
A=NaN(J,k);
B=NaN(J,k);
for i=1:k
    A(:,i)=quadv(F,0,step*i,tol);
    B(:,i)=quadv(F,step*i,1,tol);
end

tau=[1:k]*step;
tau=repmat(tau,J,1);

A=ones(J,k)-A./tau; % want probability of non-missing
B=ones(J,k)-B./(1-tau); % want probability of non-missing

pi=ones(J,k) - repmat(pi,1,k); %marginal cell probability of non-missing

KS=sqrt(abs(A-pi).*abs(B-pi).*tau.*(1-tau))./(pi.*(1-pi));

counter=[1:k]*step;

[k,I]=max(KS)
close all
figure(1)
hold on
plot(counter', KS')
plot(counter', max(KS)','--k','linewidth',2)
plot(counter', repmat(max(max(KS)),length(counter),1),':k')
hold off
title('Distance Between Missing and Nonmissing CDFs by Quantile of IRS Earnings and Demographic Cell')
xlabel '\tau'; ylabel k;

print -depsc2 -r150 ~/Output/cellCPS.eps
system('ps2pdf -dEPSCrop ~/Output/cellCPS.eps ~/Output/cellCPS.pdf')

%summary stats
KS2=max(KS');
disp('min KS')
min(KS2)
disp('median KS')
median(KS2)
disp('max KS')
max(KS2)
[maxks,bin]=max(KS2)



%summary (ages 40-49)
T=importdata('target.csv');
T=logical(T.data);
KScensus=KS(T',:);

figure(2)
hold on
plot(counter', KScensus')
plot(counter', max(KScensus)','--k','linewidth',2)
plot(counter', repmat(max(max(KScensus)),length(counter),1),':k')
hold off
title('Distance Between Missing and Nonmissing CDFs by Quantile of IRS Earnings and Demographic Cell')
xlabel '\tau'; ylabel k;
%print -depsc2 -r150 ~/Output/CPS_Censusage.eps
%system('ps2pdf -dEPSCrop ~/Output/CPS_Censusage.eps ~/Output/CPS_Censusage.pdf')




KScensus2=max(KScensus');
disp('min KS')
min(KScensus2)
disp('median KS')
median(KScensus2)
disp('max KS')
[maxks,bin]=max(KScensus2)


