clear all
set mem 500m
***Code for Kline & Santos (2012) Section 5.4***

***Build CPS-IRS file and define variables***
use "07616-0001-Data.dta", clear //load the raw ICPSR file

log using QE_logits.log, replace

**Rename variables**
ren V1053 hours
ren V1063 weeks
ren V1064 class
ren V1062 flagw
ren V1070 school

ren V1065 occ
ren V1066 ind
ren V1067 pftime
ren V1045 hhstatus
ren V1007 hhseq

ren V1071 flag
ren V1074 searn

ren V1127 sex
ren V1128 race
ren V1129 age

ren V1139 qtrscov

ren V1131 earn72
ren V1140 earn71
ren V1147 type71

ren V1171 m2wage
ren V1174 irsearn
ren V1179 rtype
ren V1194 months
ren V1198 months72
ren V1196 months73


**sample selection**
*keep if hhseq==1 //keep head of household
keep if sex==1&age>=25&age<55
drop if race>2
gen educ=school-1
drop if educ<5|weeks==0
count
drop if class==2|class==7 //drop self-employed
count


*drop occupations ala Bound and Krueger
foreach occ in 910 911 915 934 935 941 944 950 983 984 714 266 086 090 801{
	drop if occ==`occ'
	}
*drop agriculture forestry and fishing ala Bound and Krueger
drop if ind>=17&ind<=28
count


replace irsearn=. if irsearn==9999999
keep if irsearn>1000&irsearn<50000 //drop topcoded IRS earnings and outliers
count

drop if flagw>1 //drop allocated weeks
count

**Generate new variables**
gen qtrswork=weeks
recode qtrswork 2=1 3=2 4=3 5=4 6=4 7=4

recode weeks 2=7 3=20 4=33 5=43.5 6=48.5 7=51

gen black=race==2

gen miss=flag>1 if flag!=. //missing if annual earnings allocated

gen lnirsearn=ln(irsearn)
gen lnirsearnsq=lnirsearn^2

gen lnweeks=ln(weeks)

gen lnirswage=lnirsearn-lnweeks

gen irswage=irsearn/weeks



tab miss

gen agecoarse=floor(age/5)*5
gen educcoarse=10 if educ<12
replace educcoarse=12 if educ==12
replace educcoarse=14 if educ>12&educ<16
replace educcoarse=16 if educ>=16


egen cell=group(black educcoarse agecoarse)
egen N=count(lnirswage), by(cell)


gen lnirswagesq=lnirswage^2
gen agesq=age^2

*define earnings quantile
egen yrank=rank(lnirswage) if lnirswage!=., by(cell)
gen yquant=yrank/N
gen yquantsq=yquant^2

gen ageyquant=agecoarse*yquant
gen educyquant=educcoarse*yquant
gen blackyquant=black*yquant


*restrict to reasonable sized bins
keep if N>50
drop cell
egen cell=group(black educcoarse agecoarse)
count
tab miss
codebook cell

sum black educcoarse agecoarse if cell==8
preserve //going to need to restore for cell level analysis

**Run Regular Logit**

tab cell, gen(celldum)
local kmax=r(r)-1

global X="celldum1 - celldum`kmax'"

logit miss yquant yquantsq $X
mat blogit=e(b) //get starting values
test yquant yquantsq


*compute logit mfx
predict phat
gen dydx=.
gen dydx2=.
gen dydx3=.
replace dydx=phat*(1-phat)*(_b[yquant] + 2*_b[yquantsq]*.2)
replace dydx2=phat*(1-phat)*(_b[yquant] + 2*_b[yquantsq]*.5)
replace dydx3=phat*(1-phat)*(_b[yquant] + 2*_b[yquantsq]*.8)
sum dydx*
drop dydx* phat



***polynomial logit**
prog polylogit
	args lnf xb1 xb2 fe gam1 gam2 
	tempvar zb p
	qui gen double `zb'= `xb1' + `xb2' + `fe' + `gam1'*`fe' + `gam2'*`fe'  
	qui gen double `p'=exp(`zb')/(1+exp(`zb'))
	qui replace `lnf'=ln(`p') if $ML_y1==1
	qui replace `lnf'=ln(1-`p') if $ML_y1==0
end


**Run Interacted Logit**
ml model lf polylogit (miss = yquant, nocons) (yquantsq, nocons) ($X) (yquant, nocons) (yquantsq, nocons)
mat b=[blogit,0,0]
ml init b, copy
ml maximize
mat beta=e(b)

*compute mfx
gen one=1
mat bfe=beta[1,"eq3:"]
gen fe=.
mata: bfe=st_matrix("bfe")
mata: X=st_data(.,"$X one")
mata: fe=X*bfe'
mata: st_store(.,"fe",fe)
local b1=beta[1,1]
local b2=beta[1,2]
mat g1=beta[1,"eq4:"]
mat g2=beta[1,"eq5:"]
local g1=g1[1,1]
local g2=g2[1,1]
gen xb=`b1'*yquant + `b2'*yquantsq + `g1'*yquant*fe + `g2'*yquantsq*fe + fe
gen phat=exp(xb)/(1+exp(xb))
gen dydx=phat*(1-phat)*(`b1' + 2*`b2'*.2 + `g1'*fe + 2*`g2'*fe*.2)
gen dydx2=phat*(1-phat)*(`b1' + 2*`b2'*.5 + `g1'*fe + 2*`g2'*fe*.5)
gen dydx3=phat*(1-phat)*(`b1' + 2*`b2'*.8 + `g1'*fe + 2*`g2'*fe*.8) 
sum dydx*


**Output**
collapse agecoarse educcoarse black $X miss, by(cell)
gen one=1
keep if miss>0&miss<1
outsheet agecoarse educcoarse black $X one miss using design.csv, comma replace
gen target=agecoarse>=40&agecoarse<50
outsheet target using target.csv, comma replace


svmat beta
keep beta*
outsheet using coefs.csv, comma replace

drop _all
svmat blogit
outsheet using coefs_simple.csv, comma replace



***Run Logit by cell**
restore
tab cell
local kmax=r(r)

gen dydx=.
gen dydx2=.
gen dydx3=.

mat A=J(`kmax',3,.)
mat L=J(`kmax',1,.)
forvalues i=1/`kmax'{
	logit miss yquant yquantsq if cell==`i'
	mat A[`i',1]=e(b)
	mat L[`i',1]=e(ll)
	predict phat,p
	replace dydx=phat*(1-phat)*(_b[yquant] + 2*_b[yquantsq]*.2) if cell==`i'
	replace dydx2=phat*(1-phat)*(_b[yquant] + 2*_b[yquantsq]*.5) if cell==`i'
	replace dydx3=phat*(1-phat)*(_b[yquant] + 2*_b[yquantsq]*.8) if cell==`i'
	drop phat
}

sum dydx*


**Output**
collapse miss, by(cell)
svmat A
keep miss A*
outsheet using cellcoefs.csv, comma replace

svmat L
sum L1
di "LL of Cell Model is " r(sum)


log close
