

************************************************************
*      Stata Build File for Kline and Santos (2012)        *
* Builds IPUMS Extract, Imposes ACF Selection Criteria and * 
* variable definitions, and dumps to ascii file for Matlab *
* Then compares to original ACF Sample.	                   *
* Note: Original ACF sample not provided. 		   *
************************************************************

clear all
set mem 100m

do usa_00005.do //this runs an IPUMS generated script to read the raw data


**generate consistent years of schooling codes

drop if educ99<5
drop if higrad<8

replace higrad=higrad-3
gen educ=higrad if year==1980
replace educ=8 if educ99==5
replace educ=9 if educ99==6
replace educ=10 if educ99==7
replace educ=11 if educ99==8|educ99==9
replace educ=12 if educ99==10
replace educ=13 if educ99==11
replace educ=14 if educ99==12|educ99==13 //assign unspecified associates degrees (2000) to occupational for consistency with ACF build code
replace educ=15 if educ99==14
replace educ=16 if educ99==15&school==1
replace educ=17 if educ99==15&school==2
replace educ=18 if educ99==16
replace educ=19 if educ99==17
replace educ=20 if educ99==18


**PCE Index 
* Note: PCE data accessed online January 2010 at bea.gov as NIPA Table 2.3.4
* Annual index (base year==2005)

gen pce=42.118 if year==1980 //1979 value of PCE from BEA
replace pce=68.994 if year==1990 //1989 value of PCE from BEA
replace pce=87.596 if year==2000 //1999 value of PCE from BEA

replace pce=pce/68.994 //make base year 1989

replace incwage=incwage/pce //deflate earnings to 1989 dollars

gen lne=ln(incwage/wkswork1)
gen lnw=ln(incwage/(wkswork1*uhrswork))

replace lne=. if qincwage>0|qwkswork>0
replace lnw=. if qincwage>0|qwkswork>0|quhrswor>0


**drop imputed X's
*drop if qrace>0 //not dropped by ACF
drop if qage>0
drop if qeduc>0
drop if qschool>0&year>=1990

**generate regressors
gen black=race==2
gen potexp=age-educ-6
gen potexpsq=potexp^2

drop if (wkswork1==0&qwkswork==0)|(incwage==0&qincwage==0)
save work, replace

*Setup for Matlab
gen miss=lne==.
egen bin=group(educ black potexp potexpsq year)
egen N=count(bin), by(bin)
drop if N<20
tab year, sum(miss)

**Dump to ascii for Matlab**
outfile lne educ black potexp potexpsq miss using ~/data/80data.txt if year==1980, comma replace
outfile lne educ black potexp potexpsq miss using ~/data/90data.txt if year==1990, comma replace
outfile lne educ black potexp potexpsq miss using ~/data/100data.txt if year==2000, comma replace



**Compare our sample to ACF by year
use work, clear
sum age educ lne potexp potexpsq black if lne!=.&year==1980
use ACF_Data/census80, clear
sum

use work, clear
sum age educ lne potexp potexpsq black if lne!=.&year==1990
use ACF_Data/census90, clear
sum

use work, clear
sum age educ lne potexp potexpsq black if lne!=.&year==2000
use ACF_Data/census00, clear
sum


**Check median regressions

use ACF_Data/census80, clear
sqreg logwk educ black exper exper2, q(10 20 50 80 90) reps(2)
use work, clear
sqreg lne educ black potexp potexpsq if year==1980, q(10 20 50 80 90) reps(2)
sqreg lnw educ black potexp potexpsq if year==1980, q(10 20 50 80 90) reps(2)

use ACF_Data/census90, clear
sqreg logwk educ black exper exper2, q(10 20 50 80 90) reps(2)
use work, clear
sqreg lne educ black potexp potexpsq if year==1990, q(10 20 50 80 90) reps(2)
sqreg lnw educ black potexp potexpsq if year==1990, q(10 20 50 80 90) reps(2)

use ACF_Data/census00, clear
sqreg logwk educ black exper exper2, q(10 20 50 80 90) reps(2)
use work, clear
sqreg lne educ black potexp potexpsq if year==2000, q(10 20 50 80 90) reps(2)
sqreg lnw educ black potexp potexpsq if year==2000, q(10 20 50 80 90) reps(2)

