%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Builds Appendix Tables and Figures 1 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

N=1000000;

mu=norminv(.75,0,1);
R=NaN(19,1);

Fy1=NaN(20,19);
Fy0=NaN(20,19);
tau=linspace(.01,.99,20);
x=norminv(tau,0,1);

for rho=0:.05:.9
    
 Y=mvnrnd([0 mu],[1 rho; rho 1],N);
 D=Y(:,2)>0; Y=Y(:,1);
 Y1=Y(D==1); Y0=Y(D==0);
 [h,p,ks2stat] = kstest2(Y1,Y0);
 R(int8(1+rho/.05),1)=ks2stat;
 Fy1(:,int8(1+rho/.05))=ksdensity(Y1,x,'function','cdf');
 Fy0(:,int8(1+rho/.05))=ksdensity(Y0,x,'function','cdf');

end

rho=[0:.05:.9]';
[rho, R]


close all
figure(1)

c=[0 .5 .8]'*ones(1,3);
set(0,'DefaultAxesColorOrder',c)

colormap(gray)
plot(x,Fy1(:,3),x,Fy0(:,3),x,Fy1(:,11),'--',x,Fy0(:,11),'--')
legend('Observed (\rho=.1)', 'Missing (\rho=.1)', 'Observed (\rho=.5)', 'Missing (\rho=.5)',2)
title('Missing and Observed Outcome CDFs')
print -depsc2 -r150 ~/Output/appendixCDFs.eps
system('ps2pdf -dEPSCrop ~/Output/appendixCDFs.eps ~/Output/appendixCDFs.pdf')

figure(2)
plot(x,abs(Fy1(:,3)-Fy0(:,3)),x,abs(Fy1(:,11)-Fy0(:,11)))
legend('\rho=.1', '\rho=.5',2)
title('Vertical Distance Between CDFs')
print -depsc2 -r150 ~/Output/appendixdists.eps
system('ps2pdf -dEPSCrop ~/Output/appendixdists.eps ~/Output/appendixdists.pdf')



